searchData={"items":[{"type":"module","title":"FocusAtWillEx","doc":"An unofficial API client for Focusatwill.com.\n\nThis library provides functionality to interact with the Focus@Will API,\nallowing you to manage sessions, browse channels, and fetch tracks.","ref":"FocusAtWillEx.html"},{"type":"module","title":"Basic Usage - FocusAtWillEx","doc":"# Create a new session\n    {:ok, session} = FocusAtWillEx.session(\"user@example.com\", \"password\")\n\n    # Get a channel by name or ID\n    {:ok, channel} = FocusAtWillEx.get_channel(\"Chinchilla\")\n    # or\n    {:ok, channel} = FocusAtWillEx.get_channel(3104)\n\n    # Fetch a track\n    {:ok, track} = FocusAtWillEx.fetch_sequence_track(session, channel, 0, 0)","ref":"FocusAtWillEx.html#module-basic-usage"},{"type":"type","title":"FocusAtWillEx.error_result/0","doc":"An error result containing an error message or struct.","ref":"FocusAtWillEx.html#t:error_result/0"},{"type":"function","title":"FocusAtWillEx.fetch_sequence_track/4","doc":"Fetches information about a specific track from a channel.","ref":"FocusAtWillEx.html#fetch_sequence_track/4"},{"type":"function","title":"Parameters - FocusAtWillEx.fetch_sequence_track/4","doc":"* `session` - A valid Focus@Will session struct\n  * `channel` - The channel struct for which to fetch a track\n  * `energy` - Energy level for the track (-1 to 1)\n  * `slot` - Index of the track within the channel/energy combination","ref":"FocusAtWillEx.html#fetch_sequence_track/4-parameters"},{"type":"function","title":"Examples - FocusAtWillEx.fetch_sequence_track/4","doc":"{:ok, session} = FocusAtWillEx.session(\"user@example.com\", \"password\")\n    {:ok, channel} = FocusAtWillEx.get_channel(\"Chinchilla\")\n    \n    # Get a low-energy track (first slot)\n    {:ok, track} = FocusAtWillEx.fetch_sequence_track(session, channel, -1, 0)\n\n    # Get a high-energy track (first slot)\n    {:ok, track} = FocusAtWillEx.fetch_sequence_track(session, channel, 1, 0)","ref":"FocusAtWillEx.html#fetch_sequence_track/4-examples"},{"type":"function","title":"FocusAtWillEx.get_channel/1","doc":"Retrieves information about a Focus@Will channel by name or ID.","ref":"FocusAtWillEx.html#get_channel/1"},{"type":"function","title":"Examples - FocusAtWillEx.get_channel/1","doc":"# Get by name\n    {:ok, channel} = FocusAtWillEx.get_channel(\"Chinchilla\")\n\n    # Get by ID\n    {:ok, channel} = FocusAtWillEx.get_channel(3104)\n\n    # Channel not found\n    :error = FocusAtWillEx.get_channel(\"NonexistentChannel\")","ref":"FocusAtWillEx.html#get_channel/1-examples"},{"type":"function","title":"FocusAtWillEx.list_channels/0","doc":"Lists all available Focus@Will channels.\n\nReturns a map where the keys are channel IDs and values are channel structs.","ref":"FocusAtWillEx.html#list_channels/0"},{"type":"function","title":"Examples - FocusAtWillEx.list_channels/0","doc":"channels = FocusAtWillEx.list_channels()\n    Enum.each(channels, fn {id, channel} -> \n      IO.puts(\"#{channel.name} (#{id})\")\n    end)","ref":"FocusAtWillEx.html#list_channels/0-examples"},{"type":"type","title":"FocusAtWillEx.ok_result/1","doc":"A successful result containing the requested data.","ref":"FocusAtWillEx.html#t:ok_result/1"},{"type":"function","title":"FocusAtWillEx.session/2","doc":"Creates a new Focus@Will session using your credentials.\n\nReturns a session struct containing your authentication token and user information.","ref":"FocusAtWillEx.html#session/2"},{"type":"function","title":"Security Note - FocusAtWillEx.session/2","doc":"The session contains your API bearer token. Handle it securely and avoid exposing\nit in logs or sharing it with untrusted parties.","ref":"FocusAtWillEx.html#session/2-security-note"},{"type":"function","title":"Examples - FocusAtWillEx.session/2","doc":"{:ok, session} = FocusAtWillEx.session(\"user@example.com\", \"password\")\n    {:error, %FocusAtWillEx.Client.Error{}} = FocusAtWillEx.session(\"wrong@email.com\", \"bad_password\")","ref":"FocusAtWillEx.html#session/2-examples"},{"type":"module","title":"FocusAtWillEx.Channels.Parser","doc":"Deserialize a JSON string to a Channel sruct","ref":"FocusAtWillEx.Channels.Parser.html"},{"type":"function","title":"FocusAtWillEx.Channels.Parser.parse_json/1","doc":"Create channel structs from a string","ref":"FocusAtWillEx.Channels.Parser.html#parse_json/1"},{"type":"module","title":"FocusAtWillEx.Client","doc":"HTTP Client for Focus@Will API interactions","ref":"FocusAtWillEx.Client.html"},{"type":"function","title":"FocusAtWillEx.Client.fetch_sequence_track/4","doc":"Fetch track number: slot_index from channel: channel with energy_level: level","ref":"FocusAtWillEx.Client.html#fetch_sequence_track/4"},{"type":"function","title":"FocusAtWillEx.Client.new/1","doc":"","ref":"FocusAtWillEx.Client.html#new/1"},{"type":"behaviour","title":"FocusAtWillEx.ClientBehaviour","doc":"Behaviour definintion for Focus@Will API client","ref":"FocusAtWillEx.ClientBehaviour.html"},{"type":"callback","title":"FocusAtWillEx.ClientBehaviour.authenticate/2","doc":"","ref":"FocusAtWillEx.ClientBehaviour.html#c:authenticate/2"},{"type":"type","title":"FocusAtWillEx.ClientBehaviour.channel/0","doc":"","ref":"FocusAtWillEx.ClientBehaviour.html#t:channel/0"},{"type":"type","title":"FocusAtWillEx.ClientBehaviour.error/0","doc":"","ref":"FocusAtWillEx.ClientBehaviour.html#t:error/0"},{"type":"callback","title":"FocusAtWillEx.ClientBehaviour.fetch_sequence_track/4","doc":"","ref":"FocusAtWillEx.ClientBehaviour.html#c:fetch_sequence_track/4"},{"type":"type","title":"FocusAtWillEx.ClientBehaviour.response/0","doc":"","ref":"FocusAtWillEx.ClientBehaviour.html#t:response/0"},{"type":"type","title":"FocusAtWillEx.ClientBehaviour.session/0","doc":"","ref":"FocusAtWillEx.ClientBehaviour.html#t:session/0"},{"type":"module","title":"FocusAtWillEx.Session","doc":"Information about Focus@Will API session","ref":"FocusAtWillEx.Session.html"},{"type":"function","title":"FocusAtWillEx.Session.new/2","doc":"","ref":"FocusAtWillEx.Session.html#new/2"},{"type":"type","title":"FocusAtWillEx.Session.t/0","doc":"","ref":"FocusAtWillEx.Session.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.1"}}